/**
 * JASMINe
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: EventActivator.java 4798 2009-08-07 12:30:47Z alitokmen $
 * --------------------------------------------------------------------------
 */

package org.ow2.jasmine.monitoring.tests.events.osgi;

import org.mule.extras.client.MuleClient;
import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;

/**
 * Activator that will send events to the Event Switch.
 * @author Florent Benoit
 */
public class EventActivator implements BundleActivator {

	/**
	 * Dispatcher on the mule side.
	 */
	private static final String DISPATCHER = "vm://MBeanCmd_dispatcher";
	
	/**
	 * Mule Client.
	 */
	private static MuleClient muleClient = null;
	
	/**
	 * First Event.
	 */
	private static final String EVENT_1 = 
		"mbeancmd_values_v1\n" + 
		"date;time;sname;server;domain;mbean;;Item\n" + 
		"2009/09/09 09:09:09;1252480149410;service:jmx:rmi:///jndi/rmi://localhost:1099/jrmpconnector_jonas_florent;florentServer;myDomain;myProbe1;;myValue1";	

	/**
	 * Second Event.
	 */
	private static final String EVENT_2 = 
		"mbeancmd_values_v1\n" + 
		"date;time;sname;server;domain;mbean;;Item\n" + 
		"2009/09/09 09:09:09;1252480149410;service:jmx:rmi:///jndi/rmi://localhost:1099/jrmpconnector_jonas_florent;florentServer;myDomain;myProbe2;;myValue2";	

	/**
	 * Third Event.
	 */
	private static final String EVENT_3 = 
		"mbeancmd_values_v1\n" + 
		"date;time;sname;server;domain;mbean;;Item\n" + 
		"2009/09/09 09:09:09;1252480149410;service:jmx:rmi:///jndi/rmi://localhost:1099/jrmpconnector_jonas_florent;florentServer;myDomain;myProbe3;;myValue3";	
	                         
	
	public void start(final BundleContext bundleContext) throws Exception {
		System.out.println("Starting " + EventActivator.class + ", sending events on the Event Switch...");
		
		// Only one instance of the mule client
		if (muleClient == null) {
			muleClient = new MuleClient();
		}

		// Send 3 events
		muleClient.dispatch(DISPATCHER, EVENT_1, null);
		muleClient.dispatch(DISPATCHER, EVENT_2, null);
		muleClient.dispatch(DISPATCHER, EVENT_3, null);
		
	}

	public void stop(final BundleContext bundleContext) throws Exception {
		System.out.println("Stopping " + EventActivator.class + "");
	}

}
